import { type PathLike } from 'fs';
export declare class DataStore {
    #private;
    constructor();
    get(collectionName: string, key: string): any;
    entries(collectionName: string): IterableIterator<[id: string, any]>;
    set(collectionName: string, key: string, value: any): void;
    delete(collectionName: string, key: string): void;
    clear(collectionName: string): void;
    has(collectionName: string, key: string): boolean;
    hasCollection(collectionName: string): boolean;
    collections(): Map<string, Map<string, any>>;
    scopedStore(collectionName: string): ScopedDataStore;
    metaStore(collectionName: string): MetaStore;
    toString(): string;
    writeToDisk(filePath: PathLike): Promise<void>;
    static fromDisk(filePath: PathLike): Promise<DataStore>;
    static fromString(str: string): DataStore;
    static fromModule(): Promise<DataStore>;
    static fromJSON(entries: Array<[string, Array<[string, any]>]>): DataStore;
}
export interface ScopedDataStore {
    get: (key: string) => any;
    entries: () => IterableIterator<[id: string, any]>;
    set: (key: string, value: any) => void;
    delete: (key: string) => void;
    clear: () => void;
    has: (key: string) => boolean;
}
export interface MetaStore {
    get: (key: string) => string | undefined;
    set: (key: string, value: string) => void;
    has: (key: string) => boolean;
}
export declare const globalDataStore: {
    get: () => Promise<DataStore>;
    set: (store: DataStore) => void;
};
