import type { ZodSchema } from 'zod';
import type { AstroSettings } from '../@types/astro.js';
import type { AstroIntegrationLogger, Logger } from '../core/logger/core.js';
import { DataStore, type MetaStore, type ScopedDataStore } from './data-store.js';
export interface ParseDataOptions {
    /** The ID of the entry. Unique per collection */
    id: string;
    /** The raw, unvalidated data of the entry */
    data: Record<string, unknown>;
    /** An optional file path, where the entry represents a local file */
    filePath?: string;
}
export interface LoaderContext {
    collection: string;
    /** A database abstraction to store the actual data */
    store: ScopedDataStore;
    /**  A simple KV store, designed for things like sync tokens */
    meta: MetaStore;
    logger: AstroIntegrationLogger;
    settings: AstroSettings;
    /** Validates and parses the data according to the schema */
    parseData<T extends Record<string, unknown> = Record<string, unknown>>(props: ParseDataOptions): T;
}
export interface Loader<S extends ZodSchema = ZodSchema> {
    /** Unique name of the loader, e.g. the npm package name */
    name: string;
    /** Do the actual loading of the data */
    load: (context: LoaderContext) => Promise<void>;
    /** Optionally, define the schema of the data. Will be overridden by user-defined schema */
    schema?: S | Promise<S> | (() => S | Promise<S>);
    render?: (entry: any) => any;
}
export declare function syncDataLayer({ settings, logger: globalLogger, store, }: {
    settings: AstroSettings;
    logger: Logger;
    store?: DataStore;
}): Promise<void>;
